==> huaweicloudsdkmrs-3.0.82-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/show_job_exes_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowJobExesRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_exe_id': 'str'
    }

    attribute_map = {
        'job_exe_id': 'job_exe_id'
    }

    def __init__(self, job_exe_id=None):
        """ShowJobExesRequest - a model defined in huaweicloud sdk"""
        
        

        self._job_exe_id = None
        self.discriminator = None

        self.job_exe_id = job_exe_id

    @property
    def job_exe_id(self):
        """Gets the job_exe_id of this ShowJobExesRequest.

        作业ID。

        :return: The job_exe_id of this ShowJobExesRequest.
        :rtype: str
        """
        return self._job_exe_id

    @job_exe_id.setter
    def job_exe_id(self, job_exe_id):
        """Sets the job_exe_id of this ShowJobExesRequest.

        作业ID。

        :param job_exe_id: The job_exe_id of this ShowJobExesRequest.
        :type: str
        """
        self._job_exe_id = job_exe_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowJobExesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkmrs-3.0.96-py2.py3-none-any.whl: huaweicloudsdkmrs/v1/model/show_job_exes_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowJobExesRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'job_exe_id': 'str'
    }

    attribute_map = {
        'job_exe_id': 'job_exe_id'
    }

    def __init__(self, job_exe_id=None):
        """ShowJobExesRequest

        The model defined in huaweicloud sdk

        :param job_exe_id: 作业ID。
        :type job_exe_id: str
        """
        
        

        self._job_exe_id = None
        self.discriminator = None

        self.job_exe_id = job_exe_id

    @property
    def job_exe_id(self):
        """Gets the job_exe_id of this ShowJobExesRequest.

        作业ID。

        :return: The job_exe_id of this ShowJobExesRequest.
        :rtype: str
        """
        return self._job_exe_id

    @job_exe_id.setter
    def job_exe_id(self, job_exe_id):
        """Sets the job_exe_id of this ShowJobExesRequest.

        作业ID。

        :param job_exe_id: The job_exe_id of this ShowJobExesRequest.
        :type job_exe_id: str
        """
        self._job_exe_id = job_exe_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowJobExesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
